@@ -19,7 +19,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#if !defined (__COLORHUG_H_INSIDE__) && !defined (CH_COMPILATION)
+#if !defined (__COLORHUG_H_INSIDE__) && !defined (CD_COMPILATION)
 #error "Only <colorhug.h> can be included directly."
 #endif
 
@@ -34,10 +34,12 @@ G_BEGIN_DECLS
 /* device constants */
 #define	CH_USB_VID				0x273f
 #define	CH_USB_PID_BOOTLOADER			0x1000
+#define	CH_USB_PID_BOOTLOADER_DFU		0x100a
 #define	CH_USB_PID_BOOTLOADER2			0x1005
 #define	CH_USB_PID_BOOTLOADER_ALS		0x1006	/* since 1.2.9 */
 #define	CH_USB_PID_BOOTLOADER_PLUS		0x1003
 #define	CH_USB_PID_FIRMWARE			0x1001
+#define	CH_USB_PID_FIRMWARE_DFU			0x1009
 #define	CH_USB_PID_FIRMWARE2			0x1004
 #define	CH_USB_PID_FIRMWARE_ALS			0x1007	/* since 1.2.9 */
 #define	CH_USB_PID_FIRMWARE_ALS_SENSOR_HID	0x1008	/* since 1.2.11 */
@@ -346,6 +348,48 @@ G_BEGIN_DECLS
  **/
 #define	CH_CMD_SET_LEDS				0x0e
 
+/**
+ * CH_CMD_GET_ILLUMINANTS:
+ *
+ * Get the illuminant state.
+ *
+ * IN:  [1:cmd]
+ * OUT: [1:retval][1:cmd][1:illuminants]
+ *
+ * This command is available under these conditions:
+ *
+ *                |  Bootloader  |  Firmware
+ * ---------------+--------------+-----------
+ * ColorHug       |      ×       |      ×
+ * ColorHug2      |      ×       |      ×
+ * ColorHug+      |      ×       |      ✓
+ * ColorHugALS    |      ×       |      ×
+ *
+ * Since: 1.3.4
+ **/
+#define	CH_CMD_GET_ILLUMINANTS			0x15
+
+/**
+ * CH_CMD_SET_ILLUMINANTS:
+ *
+ * Set the illuminants.
+ *
+ * IN:  [1:cmd][1:illuminant]
+ * OUT: [1:retval][1:cmd]
+ *
+ * This command is available under these conditions:
+ *
+ *                |  Bootloader  |  Firmware
+ * ---------------+--------------+-----------
+ * ColorHug       |      ×       |      ×
+ * ColorHug2      |      ×       |      ×
+ * ColorHug+      |      ×       |      ✓
+ * ColorHugALS    |      ×       |      ×
+ *
+ * Since: 1.3.4
+ **/
+#define	CH_CMD_SET_ILLUMINANTS			0x16
+
 /**
  * CH_CMD_GET_DARK_OFFSETS:
  *
@@ -592,7 +636,7 @@ G_BEGIN_DECLS
  *
  * Since: 0.1.31
  **/
-#define	CH_CMD_TAKE_READING_SPECTRAL		0x50
+#define	CH_CMD_TAKE_READING_SPECTRAL		0x55
 
 /**
  * CH_CMD_GET_ADC_CALIBRATION_POS:
@@ -1296,6 +1340,58 @@ G_BEGIN_DECLS
  **/
 #define	CH_CMD_SELF_TEST			0x40
 
+/**
+ * CH_CMD_LOAD_SRAM:
+ *
+ * Load the SRAM from the EEPROM.
+ *
+ * PROTOCOLv2:
+ * bRequest:   [cmd]
+ * wValue:     0x00
+ * wIndex:     interface
+ * wLength:    0x00
+ * Direction:  DEVICE->HOST
+ * Data:       [1:error][1:cmd]
+ *
+ * This command is available under these conditions:
+ *
+ *                |  Bootloader  |  Firmware
+ * ---------------+--------------+-----------
+ * ColorHug       |      ×       |      ×
+ * ColorHug2      |      ×       |      ×
+ * ColorHug+      |      ×       |      ✓
+ * ColorHugALS    |      ×       |      ×
+ *
+ * Since: 0.1.29
+ **/
+#define	CH_CMD_LOAD_SRAM			0x41
+
+/**
+ * CH_CMD_SAVE_SRAM:
+ *
+ * Save the SRAM to the EEPROM.
+ *
+ * PROTOCOLv2:
+ * bRequest:   [cmd]
+ * wValue:     0x00
+ * wIndex:     interface
+ * wLength:    0x00
+ * Direction:  DEVICE->HOST
+ * Data:       [1:error][1:cmd]
+ *
+ * This command is available under these conditions:
+ *
+ *                |  Bootloader  |  Firmware
+ * ---------------+--------------+-----------
+ * ColorHug       |      ×       |      ×
+ * ColorHug2      |      ×       |      ×
+ * ColorHug+      |      ×       |      ✓
+ * ColorHugALS    |      ×       |      ×
+ *
+ * Since: 0.1.29
+ **/
+#define	CH_CMD_SAVE_SRAM			0x42
+
 /**
  * CH_CMD_GET_ERROR:
  *
@@ -1351,7 +1447,7 @@ G_BEGIN_DECLS
 /**
  * CH_CMD_SET_CRYPTO_KEY:
  *
- * Sets the 128 bit encyption key for the device.
+ * Sets the 128 bit encryption key for the device.
  *
  * PROTOCOLv2:
  * bRequest:   [cmd]
@@ -1374,8 +1470,9 @@ G_BEGIN_DECLS
  **/
 #define	CH_CMD_SET_CRYPTO_KEY			0x70
 
-/* these are not yet in the API */
+/* the values here are not really API */
 #define	CH_EP0_TRANSFER_SIZE			64
+#define	CH_EP0_TRANSFER_SIZE_V2			0x400	/* since 1.3.4 */
 
 /* secret code */
 #define	CH_WRITE_EEPROM_MAGIC			"Un1c0rn2"
@@ -1401,7 +1498,7 @@ G_BEGIN_DECLS
 #define CH_EEPROM_ADDR_RUNCODE_ALS		0x2000		/* since 1.2.9 */
 
 /* the number of useful samples from the the CCD */
-#define CH_CCD_SPECTRAL_RESOLUTION		3648
+#define CH_CCD_SPECTRAL_RESOLUTION		1024
 
 /* although each calibration can be stored in 60 bytes,
  * we use a full 64 byte block */
@@ -1452,6 +1549,15 @@ typedef enum {
 	CH_STATUS_LED_BLUE	= 1 << 2	/* Since: 0.1.29 */
 } ChStatusLed;
 
+/* Illuminants: possible bitfield values */
+typedef enum {
+	CH_ILLUMINANT_NONE	= 0,		/* Since: 1.3.4 */
+	CH_ILLUMINANT_A		= 1 << 0,	/* Since: 1.3.4 */
+	CH_ILLUMINANT_UV	= 1 << 1,	/* Since: 1.3.4 */
+	/*< private >*/
+	CH_ILLUMINANT_LAST
+} ChIlluminant;
+
 /* what frequency divider to use */
 typedef enum {
 	CH_FREQ_SCALE_0,
@@ -1532,6 +1638,14 @@ typedef enum {
 	CH_DEVICE_MODE_LAST
 } ChDeviceMode;
 
+typedef enum {
+	CH_SPECTRUM_KIND_RAW		= 0x00,	/* since 1.3.4 */
+	CH_SPECTRUM_KIND_DARK_CAL	= 0x01,	/* since 1.3.4 */
+	CH_SPECTRUM_KIND_TEMP_CAL	= 0x02,	/* since 1.3.4 */
+	CH_SPECTRUM_KIND_IRRADIANCE_CAL	= 0x03,	/* since 1.3.4 */
+	CH_SPECTRUM_KIND_LAST
+} ChSpectrumKind;
+
 typedef guint8 ChCmd;
 
 /* prototypes */
