@@ -19,7 +19,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#if !defined (__COLORHUG_H_INSIDE__) && !defined (CH_COMPILATION)
+#if !defined (__COLORHUG_H_INSIDE__) && !defined (CD_COMPILATION)
 #error "Only <colorhug.h> can be included directly."
 #endif
 
